from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ImpedanceCls:
	"""Impedance commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("impedance", core, parent)

	def set(self, impedance: enums.ImpG50G10K, userIx=repcap.UserIx.Default) -> None:
		"""SCPI: CONNector:USER<CH>:TRIGger:IMPedance \n
		Snippet: driver.connector.user.trigger.impedance.set(impedance = enums.ImpG50G10K.G10K, userIx = repcap.UserIx.Default) \n
		Selects the input impedance for the external trigger/clock inputs, when method RsSgt.Connector.User.Omode.set is set to
		TRIGger or CIN/COUT. \n
			:param impedance: G50| G10K G10K Provided only for backward compatibility with other R&S signal generators. The R&S SGT accepts this values and maps it automatically to G1K.
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
		"""
		param = Conversions.enum_scalar_to_str(impedance, enums.ImpG50G10K)
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		self._core.io.write(f'CONNector:USER{userIx_cmd_val}:TRIGger:IMPedance {param}')

	# noinspection PyTypeChecker
	def get(self, userIx=repcap.UserIx.Default) -> enums.ImpG50G10K:
		"""SCPI: CONNector:USER<CH>:TRIGger:IMPedance \n
		Snippet: value: enums.ImpG50G10K = driver.connector.user.trigger.impedance.get(userIx = repcap.UserIx.Default) \n
		Selects the input impedance for the external trigger/clock inputs, when method RsSgt.Connector.User.Omode.set is set to
		TRIGger or CIN/COUT. \n
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: impedance: G50| G10K G10K Provided only for backward compatibility with other R&S signal generators. The R&S SGT accepts this values and maps it automatically to G1K."""
		userIx_cmd_val = self._cmd_group.get_repcap_cmd_value(userIx, repcap.UserIx)
		response = self._core.io.query_str(f'CONNector:USER{userIx_cmd_val}:TRIGger:IMPedance?')
		return Conversions.str_to_scalar_enum(response, enums.ImpG50G10K)



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SettingCls:
	"""Setting commands group definition. 5 total commands, 1 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("setting", core, parent)

	@property
	def store(self):
		"""store commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_store'):
			from .Store import StoreCls
			self._store = StoreCls(self._core, self._cmd_group)
		return self._store

	def get_catalog(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:XMRadio:SETTing:CATalog \n
		Snippet: value: List[str] = driver.source.bb.xmRadio.setting.get_catalog() \n
		No command help available \n
			:return: catalog: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:XMRadio:SETTing:CATalog?')
		return Conversions.str_to_str_list(response)

	def delete(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:XMRadio:SETTing:DELete \n
		Snippet: driver.source.bb.xmRadio.setting.delete(filename = '1') \n
		No command help available \n
			:param filename: No help available
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:XMRadio:SETTing:DELete {param}')

	def load(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:XMRadio:SETTing:LOAD \n
		Snippet: driver.source.bb.xmRadio.setting.load(filename = '1') \n
		No command help available \n
			:param filename: No help available
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:XMRadio:SETTing:LOAD {param}')

	def clone(self) -> 'SettingCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SettingCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BbinCls:
	"""Bbin commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bbin", core, parent)

	def get_rb_error(self) -> bool:
		"""SCPI: TEST<HW>:BBIN:RBERror \n
		Snippet: value: bool = driver.test.bbin.get_rb_error() \n
		No command help available \n
			:return: rb_error: No help available
		"""
		response = self._core.io.query_str('TEST<HwInstance>:BBIN:RBERror?')
		return Conversions.str_to_bool(response)

	def get_value(self) -> bool:
		"""SCPI: TEST:BBIN \n
		Snippet: value: bool = driver.test.bbin.get_value() \n
		This command performs a selftest on the baseband input hardware options. Several analog diagnostics points are checked to
		verify the correct function of the module. \n
			:return: bbin: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('TEST:BBIN?')
		return Conversions.str_to_bool(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SecurityCls:
	"""Security commands group definition. 16 total commands, 4 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("security", core, parent)

	@property
	def mmem(self):
		"""mmem commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_mmem'):
			from .Mmem import MmemCls
			self._mmem = MmemCls(self._core, self._cmd_group)
		return self._mmem

	@property
	def network(self):
		"""network commands group. 12 Sub-classes, 0 commands."""
		if not hasattr(self, '_network'):
			from .Network import NetworkCls
			self._network = NetworkCls(self._core, self._cmd_group)
		return self._network

	@property
	def usbStorage(self):
		"""usbStorage commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_usbStorage'):
			from .UsbStorage import UsbStorageCls
			self._usbStorage = UsbStorageCls(self._core, self._cmd_group)
		return self._usbStorage

	@property
	def volMode(self):
		"""volMode commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_volMode'):
			from .VolMode import VolModeCls
			self._volMode = VolModeCls(self._core, self._cmd_group)
		return self._volMode

	def get_state(self) -> bool:
		"""SCPI: SYSTem:SECurity:[STATe] \n
		Snippet: value: bool = driver.system.security.get_state() \n
		No command help available \n
			:return: state: No help available
		"""
		response = self._core.io.query_str('SYSTem:SECurity:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: SYSTem:SECurity:[STATe] \n
		Snippet: driver.system.security.set_state(state = False) \n
		No command help available \n
			:param state: No help available
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SYSTem:SECurity:STATe {param}')

	def clone(self) -> 'SecurityCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SecurityCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MarkerCls:
	"""Marker commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("marker", core, parent)

	# noinspection PyTypeChecker
	def get_esegment(self) -> enums.ArbWaveSegmRest:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:WSEGment:CONFigure:MARKer:ESEGment \n
		Snippet: value: enums.ArbWaveSegmRest = driver.source.bb.arbitrary.wsegment.configure.marker.get_esegment() \n
		Enables/disables the generation of an additional marker restart signal in the output waveform file. If additional marker
		generation is enabled, the existing marker signals in the individual segment waveform files are not considered. \n
			:return: mode: OFF| MRK1| MRK2| MRK3| MRK4 OFF No additional marker is generated. MRK1|MRK2|MRK3|MRK4 Generates a restart marker signal at the beginning of each segment for the corresponding marker. The segment begin is defined by the low-high slope of the marker. This applies for switching between two segments as well as in case of segment replay.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:WSEGment:CONFigure:MARKer:ESEGment?')
		return Conversions.str_to_scalar_enum(response, enums.ArbWaveSegmRest)

	def set_esegment(self, mode: enums.ArbWaveSegmRest) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:WSEGment:CONFigure:MARKer:ESEGment \n
		Snippet: driver.source.bb.arbitrary.wsegment.configure.marker.set_esegment(mode = enums.ArbWaveSegmRest.MRK1) \n
		Enables/disables the generation of an additional marker restart signal in the output waveform file. If additional marker
		generation is enabled, the existing marker signals in the individual segment waveform files are not considered. \n
			:param mode: OFF| MRK1| MRK2| MRK3| MRK4 OFF No additional marker is generated. MRK1|MRK2|MRK3|MRK4 Generates a restart marker signal at the beginning of each segment for the corresponding marker. The segment begin is defined by the low-high slope of the marker. This applies for switching between two segments as well as in case of segment replay.
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.ArbWaveSegmRest)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:WSEGment:CONFigure:MARKer:ESEGment {param}')

	# noinspection PyTypeChecker
	def get_fsegment(self) -> enums.ArbWaveSegmRest:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:WSEGment:CONFigure:MARKer:FSEGment \n
		Snippet: value: enums.ArbWaveSegmRest = driver.source.bb.arbitrary.wsegment.configure.marker.get_fsegment() \n
		Enables/disables the generation of an additional marker restart signal in the output waveform file. If additional marker
		generation is enabled, the existing marker signals in the individual segment waveform files are not considered. \n
			:return: mode: OFF| MRK1| MRK2| MRK3| MRK4 OFF No additional marker is generated. MRK1|MRK2|MRK3|MRK4 Generates a restart marker signal at the beginning of the first segment for the corresponding marker. Use this setting to generate a restart marker for the complete sequence.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:WSEGment:CONFigure:MARKer:FSEGment?')
		return Conversions.str_to_scalar_enum(response, enums.ArbWaveSegmRest)

	def set_fsegment(self, mode: enums.ArbWaveSegmRest) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:WSEGment:CONFigure:MARKer:FSEGment \n
		Snippet: driver.source.bb.arbitrary.wsegment.configure.marker.set_fsegment(mode = enums.ArbWaveSegmRest.MRK1) \n
		Enables/disables the generation of an additional marker restart signal in the output waveform file. If additional marker
		generation is enabled, the existing marker signals in the individual segment waveform files are not considered. \n
			:param mode: OFF| MRK1| MRK2| MRK3| MRK4 OFF No additional marker is generated. MRK1|MRK2|MRK3|MRK4 Generates a restart marker signal at the beginning of the first segment for the corresponding marker. Use this setting to generate a restart marker for the complete sequence.
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.ArbWaveSegmRest)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:WSEGment:CONFigure:MARKer:FSEGment {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.ArbWaveSegmMarkMode:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:WSEGment:CONFigure:MARKer:MODE \n
		Snippet: value: enums.ArbWaveSegmMarkMode = driver.source.bb.arbitrary.wsegment.configure.marker.get_mode() \n
		Defines the way the marker information within the separate segments is processed. \n
			:return: mode: IGNore| TAKE IGNore The marker information carried in the individual segment waveform files is not considered. TAKE The output waveform file contains the marker information as configured in the individual waveform files.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:WSEGment:CONFigure:MARKer:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.ArbWaveSegmMarkMode)

	def set_mode(self, mode: enums.ArbWaveSegmMarkMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:WSEGment:CONFigure:MARKer:MODE \n
		Snippet: driver.source.bb.arbitrary.wsegment.configure.marker.set_mode(mode = enums.ArbWaveSegmMarkMode.IGNore) \n
		Defines the way the marker information within the separate segments is processed. \n
			:param mode: IGNore| TAKE IGNore The marker information carried in the individual segment waveform files is not considered. TAKE The output waveform file contains the marker information as configured in the individual waveform files.
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.ArbWaveSegmMarkMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:WSEGment:CONFigure:MARKer:MODE {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OutputCls:
	"""Output commands group definition. 9 total commands, 6 Subgroups, 0 group commands
	Repeated Capability: Output, default value after init: Output.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("output", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_output_get', 'repcap_output_set', repcap.Output.Nr1)

	def repcap_output_set(self, output: repcap.Output) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Output.Default
		Default value after init: Output.Nr1"""
		self._cmd_group.set_repcap_enum_value(output)

	def repcap_output_get(self) -> repcap.Output:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def delay(self):
		"""delay commands group. 2 Sub-classes, 2 commands."""
		if not hasattr(self, '_delay'):
			from .Delay import DelayCls
			self._delay = DelayCls(self._core, self._cmd_group)
		return self._delay

	@property
	def mcmPosition(self):
		"""mcmPosition commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mcmPosition'):
			from .McmPosition import McmPositionCls
			self._mcmPosition = McmPositionCls(self._core, self._cmd_group)
		return self._mcmPosition

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	@property
	def offTime(self):
		"""offTime commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_offTime'):
			from .OffTime import OffTimeCls
			self._offTime = OffTimeCls(self._core, self._cmd_group)
		return self._offTime

	@property
	def ontime(self):
		"""ontime commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ontime'):
			from .Ontime import OntimeCls
			self._ontime = OntimeCls(self._core, self._cmd_group)
		return self._ontime

	@property
	def period(self):
		"""period commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_period'):
			from .Period import PeriodCls
			self._period = PeriodCls(self._core, self._cmd_group)
		return self._period

	def clone(self) -> 'OutputCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = OutputCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DohertyCls:
	"""Doherty commands group definition. 31 total commands, 6 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("doherty", core, parent)

	@property
	def amam(self):
		"""amam commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_amam'):
			from .Amam import AmamCls
			self._amam = AmamCls(self._core, self._cmd_group)
		return self._amam

	@property
	def amPm(self):
		"""amPm commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_amPm'):
			from .AmPm import AmPmCls
			self._amPm = AmPmCls(self._core, self._cmd_group)
		return self._amPm

	@property
	def inputPy(self):
		"""inputPy commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_inputPy'):
			from .InputPy import InputPyCls
			self._inputPy = InputPyCls(self._core, self._cmd_group)
		return self._inputPy

	@property
	def output(self):
		"""output commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_output'):
			from .Output import OutputCls
			self._output = OutputCls(self._core, self._cmd_group)
		return self._output

	@property
	def pin(self):
		"""pin commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_pin'):
			from .Pin import PinCls
			self._pin = PinCls(self._core, self._cmd_group)
		return self._pin

	@property
	def shaping(self):
		"""shaping commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_shaping'):
			from .Shaping import ShapingCls
			self._shaping = ShapingCls(self._core, self._cmd_group)
		return self._shaping

	# noinspection PyTypeChecker
	def get_scale(self) -> enums.IqOutEnvScale:
		"""SCPI: [SOURce<HW>]:IQ:DOHerty:SCALe \n
		Snippet: value: enums.IqOutEnvScale = driver.source.iq.doherty.get_scale() \n
		No command help available \n
			:return: scale: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:IQ:DOHerty:SCALe?')
		return Conversions.str_to_scalar_enum(response, enums.IqOutEnvScale)

	def set_scale(self, scale: enums.IqOutEnvScale) -> None:
		"""SCPI: [SOURce<HW>]:IQ:DOHerty:SCALe \n
		Snippet: driver.source.iq.doherty.set_scale(scale = enums.IqOutEnvScale.POWer) \n
		No command help available \n
			:param scale: No help available
		"""
		param = Conversions.enum_scalar_to_str(scale, enums.IqOutEnvScale)
		self._core.io.write(f'SOURce<HwInstance>:IQ:DOHerty:SCALe {param}')

	def clone(self) -> 'DohertyCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DohertyCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DiagnosticCls:
	"""Diagnostic commands group definition. 16 total commands, 6 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("diagnostic", core, parent)

	@property
	def bgInfo(self):
		"""bgInfo commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_bgInfo'):
			from .BgInfo import BgInfoCls
			self._bgInfo = BgInfoCls(self._core, self._cmd_group)
		return self._bgInfo

	@property
	def debug(self):
		"""debug commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_debug'):
			from .Debug import DebugCls
			self._debug = DebugCls(self._core, self._cmd_group)
		return self._debug

	@property
	def eeprom(self):
		"""eeprom commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_eeprom'):
			from .Eeprom import EepromCls
			self._eeprom = EepromCls(self._core, self._cmd_group)
		return self._eeprom

	@property
	def info(self):
		"""info commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_info'):
			from .Info import InfoCls
			self._info = InfoCls(self._core, self._cmd_group)
		return self._info

	@property
	def point(self):
		"""point commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_point'):
			from .Point import PointCls
			self._point = PointCls(self._core, self._cmd_group)
		return self._point

	@property
	def service(self):
		"""service commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_service'):
			from .Service import ServiceCls
			self._service = ServiceCls(self._core, self._cmd_group)
		return self._service

	def clone(self) -> 'DiagnosticCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DiagnosticCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LockCls:
	"""Lock commands group definition. 10 total commands, 5 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("lock", core, parent)

	@property
	def name(self):
		"""name commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_name'):
			from .Name import NameCls
			self._name = NameCls(self._core, self._cmd_group)
		return self._name

	@property
	def owner(self):
		"""owner commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_owner'):
			from .Owner import OwnerCls
			self._owner = OwnerCls(self._core, self._cmd_group)
		return self._owner

	@property
	def release(self):
		"""release commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_release'):
			from .Release import ReleaseCls
			self._release = ReleaseCls(self._core, self._cmd_group)
		return self._release

	@property
	def request(self):
		"""request commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_request'):
			from .Request import RequestCls
			self._request = RequestCls(self._core, self._cmd_group)
		return self._request

	@property
	def shared(self):
		"""shared commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_shared'):
			from .Shared import SharedCls
			self._shared = SharedCls(self._core, self._cmd_group)
		return self._shared

	def get_timeout(self) -> int:
		"""SCPI: SYSTem:LOCK:TIMeout \n
		Snippet: value: int = driver.system.lock.get_timeout() \n
		No command help available \n
			:return: time_ms: No help available
		"""
		response = self._core.io.query_str('SYSTem:LOCK:TIMeout?')
		return Conversions.str_to_int(response)

	def set_timeout(self, time_ms: int) -> None:
		"""SCPI: SYSTem:LOCK:TIMeout \n
		Snippet: driver.system.lock.set_timeout(time_ms = 1) \n
		No command help available \n
			:param time_ms: No help available
		"""
		param = Conversions.decimal_value_to_str(time_ms)
		self._core.io.write(f'SYSTem:LOCK:TIMeout {param}')

	def clone(self) -> 'LockCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = LockCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BgInfoCls:
	"""BgInfo commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bgInfo", core, parent)

	def get_catalog(self) -> List[str]:
		"""SCPI: DIAGnostic<HW>:BGINfo:CATalog \n
		Snippet: value: List[str] = driver.diagnostic.bgInfo.get_catalog() \n
		No command help available \n
			:return: catalog: No help available
		"""
		response = self._core.io.query_str('DIAGnostic<HwInstance>:BGINfo:CATalog?')
		return Conversions.str_to_str_list(response)

	def get_value(self) -> str:
		"""SCPI: DIAGnostic<HW>:BGINfo \n
		Snippet: value: str = driver.diagnostic.bgInfo.get_value() \n
		No command help available \n
			:return: bg_info: No help available
		"""
		response = self._core.io.query_str('DIAGnostic<HwInstance>:BGINfo?')
		return trim_str_response(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CommunicateCls:
	"""Communicate commands group definition. 22 total commands, 8 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("communicate", core, parent)

	@property
	def gpib(self):
		"""gpib commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_gpib'):
			from .Gpib import GpibCls
			self._gpib = GpibCls(self._core, self._cmd_group)
		return self._gpib

	@property
	def hislip(self):
		"""hislip commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hislip'):
			from .Hislip import HislipCls
			self._hislip = HislipCls(self._core, self._cmd_group)
		return self._hislip

	@property
	def network(self):
		"""network commands group. 3 Sub-classes, 3 commands."""
		if not hasattr(self, '_network'):
			from .Network import NetworkCls
			self._network = NetworkCls(self._core, self._cmd_group)
		return self._network

	@property
	def pciExpress(self):
		"""pciExpress commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pciExpress'):
			from .PciExpress import PciExpressCls
			self._pciExpress = PciExpressCls(self._core, self._cmd_group)
		return self._pciExpress

	@property
	def scpi(self):
		"""scpi commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_scpi'):
			from .Scpi import ScpiCls
			self._scpi = ScpiCls(self._core, self._cmd_group)
		return self._scpi

	@property
	def serial(self):
		"""serial commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_serial'):
			from .Serial import SerialCls
			self._serial = SerialCls(self._core, self._cmd_group)
		return self._serial

	@property
	def socket(self):
		"""socket commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_socket'):
			from .Socket import SocketCls
			self._socket = SocketCls(self._core, self._cmd_group)
		return self._socket

	@property
	def usb(self):
		"""usb commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_usb'):
			from .Usb import UsbCls
			self._usb = UsbCls(self._core, self._cmd_group)
		return self._usb

	def clone(self) -> 'CommunicateCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CommunicateCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



"""VisaSession for simulated sessions."""

import threading
from typing import Callable, Dict, AnyStr

from . import InstrumentSettings
from .StreamReader import StreamReader
from .StreamWriter import StreamWriter


# noinspection PyMethodMayBeStatic,PyUnusedLocal
class VisaSessionSim(object):
	"""Visa session in simulation mode.
	Provides the properties for the simulation mode.
	Also serves as a cache for the SCPI command values: If you query a SCPI command value, it returns the last set value by that SCPI command."""

	def __init__(self, resource_name: str, settings: InstrumentSettings, direct_session=None):
		self.reusing_session = direct_session is not None
		# noinspection PyTypeChecker
		self._data_chunk_size: int = None
		# noinspection PyTypeChecker
		self._lock: threading.RLock = None

		# Event handlers
		# noinspection PyTypeChecker
		self.on_read_chunk_handler: Callable = None
		"""If assigned a handler, the VisaSession sends it event on each read chunk transfer."""
		# noinspection PyTypeChecker
		self.on_write_chunk_handler: Callable = None
		"""If assigned a handler, the VisaSession sends it event on each write chunk transfer."""
		self.io_events_include_data: bool = False
		"""If true, the VisaSession events sent to on_read_chunk_handler and on_write_chunk_handler contain transferred data."""

		self.manufacturer: str = 'Rohde&Schwarz'
		self.resource_name = resource_name
		self.vxi_capable = True
		self.encoding = settings.encoding  # default encoder between bytes and string

		# Changeable settings
		self.opc_timeout = 10000 if settings.opc_timeout == 0 else settings.opc_timeout
		self.visa_timeout = settings.visa_timeout
		self.data_chunk_size = settings.io_segment_size

		self._last_cmd = None

		# If the return value is written to a cache, this flag signals if it was a cached value
		self.cached_to_stream = False

		# cache command values dictionary
		self._cmd_vals_cache: Dict[str, AnyStr] = {}

		# Decide, whether to create a new thread lock or the existing one from the direct_session
		if direct_session and hasattr(direct_session, 'session_thread_rlock'):
			rlock = direct_session.session_thread_rlock
			if isinstance(rlock, type(threading.RLock())):
				self.assign_lock(rlock)
		if self.get_lock() is None:
			# The existing session did not have a thread lock, assign a new one
			self.assign_lock(threading.RLock())

		if self.reusing_session:
			self.resource_name = direct_session.resource_name

	def assign_lock(self, lock: threading.RLock) -> None:
		"""Assigns the provided thread lock. The lock is only used by the parent class Instrument."""
		self._lock = lock

	def get_lock(self) -> threading.RLock:
		"""Returns the current RLock object."""
		return self._lock

	def _update_cmd_vals_cache(self, cmd: str, param: AnyStr = None) -> None:
		"""Parses out the parameter from the command and stores/updates them in the cache"""
		aux = cmd.split(' ', 1)
		if len(aux) < 2:
			return
		headers = aux[0].strip().lower()
		param = aux[1].strip()
		self._cmd_vals_cache[headers] = param

	def _update_cmd_vals_cache_split(self, cmd: str, param: AnyStr) -> None:
		"""Stores/updates cmd and param in the cache"""
		headers = cmd.strip().lower()
		self._cmd_vals_cache[headers] = param

	def _get_cmd_cached_value(self, cmd: str) -> str or None:
		"""Returns cached parameter to the corresponding command
		Returns None of the command is not found in the cache"""
		aux = cmd.split('?', 1)
		headers = aux[0].strip().lower()
		return self._cmd_vals_cache.get(headers, None)

	def get_last_sent_cmd(self) -> str:
		"""Returns the last commands sent to the instrument"""
		return self._last_cmd

	def is_rsnrp_session(self) -> bool:
		"""Returns True, if the current session is a NRP-Z session"""
		return False

	def query_syst_error(self) -> str or None:
		"""Returns one response to the SYSTEM:ERROR? query."""
		return None

	def query_all_syst_errors(self) -> list or None:
		"""Returns all errors in the instrument's error queue.
		If no error is detected, the return value is None."""
		return None

	def clear_before_read(self) -> None:
		"""Clears IO buffers and the ESR register before reading/writing responses synchronized with *OPC."""
		return

	def clear(self) -> None:
		"""Perform VISA viClear conditionally based on the instrument settings."""
		return

	def write(self, cmd: str) -> None:
		"""Writes command to the instrument."""
		self._last_cmd = cmd
		self._update_cmd_vals_cache(cmd)
		return

	def query_str(self, query: str) -> str:
		"""Queries the instrument and reads the response as string.
		The length of the string is not limited. The response is then trimmed for trailing LF."""
		self._last_cmd = query
		cached = self._get_cmd_cached_value(query)
		return 'Simulating' if cached is None else cached

	def write_with_opc(self, cmd: str, timeout: int = None) -> None:
		"""Sends command with OPC-sync.
		If you do not provide timeout, the method uses current opc_timeout."""
		self.write(cmd)

	def query_str_with_opc(self, query: str, timeout: int = None, context: str = 'Query string with OPC') -> str:
		"""Query string with OPC synchronization.
		The response is trimmed for any trailing LF.
		If you do not provide timeout, the method uses current opc_timeout."""
		return self.query_str(query)

	def query_opc(self, timeout: int = 0) -> bool:
		"""Sends *OPC? query and reads the result."""
		return True

	def query_and_clear_esr(self) -> int:
		"""Sends *ESR? query and reads the result."""
		return 0

	def error_in_error_queue(self) -> bool:
		"""Returns true, if error queue contains at least one error."""
		return False

	def reset_ese_sre(self) -> None:
		"""Resets the status of ESE and SRE registers to default values."""
		return

	def write_bin_block(self, cmd: str, data_stream: StreamReader) -> None:
		"""Writes all the payload as binary data block to the instrument.
		The binary data header is added at the beginning of the transmission automatically."""
		self._last_cmd = cmd
		param = data_stream.read()
		self._update_cmd_vals_cache_split(cmd, param)

	def query_bin_block(self, query: str, stream: StreamWriter, exc_if_not_bin: bool = True) -> None:
		"""Query binary data block and returns it as byte data."""
		self._last_cmd = query
		cached = self._get_cmd_cached_value(query)

		if cached is None:
			stream.write(bytes([0, 1, 2, 3, 4, 5, 6, 7, 8, 65, 66]))
			self.cached_to_stream = False
		else:
			if isinstance(cached, str):
				stream.switch_to_string_data(self.encoding)
			stream.write(cached)
			self.cached_to_stream = True

	def query_bin_block_with_opc(self, query: str, stream: StreamWriter, exc_if_not_bin: bool = True, timeout: int = None) -> None:
		"""Query binary data block with OPC and returns it as byte data."""
		self.query_bin_block(query, stream)

	def read_up_to_char(self, stop_chars: bytes, max_cnt: int) -> bytes:
		"""Reads until one of the stop_chars is read or the max_cnt is reached, or EOT is detected.
		Returns the read data including the stop character."""
		return b'Simulating'

	def get_session_handle(self) -> object:
		"""Returns the underlying pyvisa session."""
		return f"Simulating session, resource name '{self.resource_name}'"

	def close(self) -> None:
		"""Closes the Visa session.
		If the object was created with the direct session input, the session is not closed."""
		return



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PowerCls:
	"""Power commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("power", core, parent)

	def get_offset(self) -> float:
		"""SCPI: [SOURce<HW>]:IQ:OUTPut:[ANALog]:ENVelope:POWer:OFFSet \n
		Snippet: value: float = driver.source.iq.output.analog.envelope.power.get_offset() \n
		Queries the current power offset, that is the sum of enabled 'RF Level > Offset' and 'User Correction'. \n
			:return: power_offset: float Range: -200 to 200
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:IQ:OUTPut:ANALog:ENVelope:POWer:OFFSet?')
		return Conversions.str_to_float(response)



from typing import List

from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Types import DataType
from ...Internal.Utilities import trim_str_response
from ...Internal.StructBase import StructBase
from ...Internal.ArgStruct import ArgStruct
from ...Internal.ArgSingleList import ArgSingleList
from ...Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DateCls:
	"""Date commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("date", core, parent)

	def set(self, year: List[int], month: int, day: int) -> None:
		"""SCPI: SYSTem:DATE \n
		Snippet: driver.system.date.set(year = [1, 2, 3], month = 1, day = 1) \n
		No command help available \n
			:param year: No help available
			:param month: No help available
			:param day: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle.as_open_list('year', year, DataType.IntegerList, None), ArgSingle('month', month, DataType.Integer), ArgSingle('day', day, DataType.Integer))
		self._core.io.write(f'SYSTem:DATE {param}'.rstrip())

	# noinspection PyTypeChecker
	class DateStruct(StructBase):
		"""Response structure. Fields: \n
			- Year: List[int]: No parameter help available
			- Month: int: No parameter help available
			- Day: int: No parameter help available"""
		__meta_args_list = [
			ArgStruct('Year', DataType.IntegerList, None, False, True, 1),
			ArgStruct.scalar_int('Month'),
			ArgStruct.scalar_int('Day')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Year: List[int] = None
			self.Month: int = None
			self.Day: int = None

	def get(self) -> DateStruct:
		"""SCPI: SYSTem:DATE \n
		Snippet: value: DateStruct = driver.system.date.get() \n
		No command help available \n
			:return: structure: for return value, see the help for DateStruct structure arguments."""
		return self._core.io.query_struct(f'SYSTem:DATE?', self.__class__.DateStruct())

	def get_local(self) -> str:
		"""SCPI: SYSTem:DATE:LOCal \n
		Snippet: value: str = driver.system.date.get_local() \n
		No command help available \n
			:return: pseudo_string: No help available
		"""
		response = self._core.io.query_str('SYSTem:DATE:LOCal?')
		return trim_str_response(response)

	def set_local(self, pseudo_string: str) -> None:
		"""SCPI: SYSTem:DATE:LOCal \n
		Snippet: driver.system.date.set_local(pseudo_string = '1') \n
		No command help available \n
			:param pseudo_string: No help available
		"""
		param = Conversions.value_to_quoted_str(pseudo_string)
		self._core.io.write(f'SYSTem:DATE:LOCal {param}')

	def get_utc(self) -> str:
		"""SCPI: SYSTem:DATE:UTC \n
		Snippet: value: str = driver.system.date.get_utc() \n
		No command help available \n
			:return: pseudo_string: No help available
		"""
		response = self._core.io.query_str('SYSTem:DATE:UTC?')
		return trim_str_response(response)

	def set_utc(self, pseudo_string: str) -> None:
		"""SCPI: SYSTem:DATE:UTC \n
		Snippet: driver.system.date.set_utc(pseudo_string = '1') \n
		No command help available \n
			:param pseudo_string: No help available
		"""
		param = Conversions.value_to_quoted_str(pseudo_string)
		self._core.io.write(f'SYSTem:DATE:UTC {param}')



from typing import List

from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DexchangeCls:
	"""Dexchange commands group definition. 12 total commands, 3 Subgroups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dexchange", core, parent)

	@property
	def execute(self):
		"""execute commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_execute'):
			from .Execute import ExecuteCls
			self._execute = ExecuteCls(self._core, self._cmd_group)
		return self._execute

	@property
	def template(self):
		"""template commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_template'):
			from .Template import TemplateCls
			self._template = TemplateCls(self._core, self._cmd_group)
		return self._template

	@property
	def transaction(self):
		"""transaction commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_transaction'):
			from .Transaction import TransactionCls
			self._transaction = TransactionCls(self._core, self._cmd_group)
		return self._transaction

	def get_catalog(self) -> List[str]:
		"""SCPI: SYSTem:DEXChange:CATalog \n
		Snippet: value: List[str] = driver.system.dexchange.get_catalog() \n
		No command help available \n
			:return: catalog: No help available
		"""
		response = self._core.io.query_str('SYSTem:DEXChange:CATalog?')
		return Conversions.str_to_str_list(response)

	def get_debug(self) -> bool:
		"""SCPI: SYSTem:DEXChange:DEBug \n
		Snippet: value: bool = driver.system.dexchange.get_debug() \n
		No command help available \n
			:return: debug: No help available
		"""
		response = self._core.io.query_str('SYSTem:DEXChange:DEBug?')
		return Conversions.str_to_bool(response)

	def set_debug(self, debug: bool) -> None:
		"""SCPI: SYSTem:DEXChange:DEBug \n
		Snippet: driver.system.dexchange.set_debug(debug = False) \n
		No command help available \n
			:param debug: No help available
		"""
		param = Conversions.bool_to_str(debug)
		self._core.io.write(f'SYSTem:DEXChange:DEBug {param}')

	def delete(self, filename: str) -> None:
		"""SCPI: SYSTem:DEXChange:DELete \n
		Snippet: driver.system.dexchange.delete(filename = '1') \n
		No command help available \n
			:param filename: No help available
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SYSTem:DEXChange:DELete {param}')

	# noinspection PyTypeChecker
	def get_format_py(self) -> enums.DevExpFormat:
		"""SCPI: SYSTem:DEXChange:FORMat \n
		Snippet: value: enums.DevExpFormat = driver.system.dexchange.get_format_py() \n
		No command help available \n
			:return: format_py: No help available
		"""
		response = self._core.io.query_str('SYSTem:DEXChange:FORMat?')
		return Conversions.str_to_scalar_enum(response, enums.DevExpFormat)

	def set_format_py(self, format_py: enums.DevExpFormat) -> None:
		"""SCPI: SYSTem:DEXChange:FORMat \n
		Snippet: driver.system.dexchange.set_format_py(format_py = enums.DevExpFormat.CGPRedefined) \n
		No command help available \n
			:param format_py: No help available
		"""
		param = Conversions.enum_scalar_to_str(format_py, enums.DevExpFormat)
		self._core.io.write(f'SYSTem:DEXChange:FORMat {param}')

	def get_select(self) -> str:
		"""SCPI: SYSTem:DEXChange:SELect \n
		Snippet: value: str = driver.system.dexchange.get_select() \n
		No command help available \n
			:return: filename: No help available
		"""
		response = self._core.io.query_str('SYSTem:DEXChange:SELect?')
		return trim_str_response(response)

	def set_select(self, filename: str) -> None:
		"""SCPI: SYSTem:DEXChange:SELect \n
		Snippet: driver.system.dexchange.set_select(filename = '1') \n
		No command help available \n
			:param filename: No help available
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SYSTem:DEXChange:SELect {param}')

	def clone(self) -> 'DexchangeCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DexchangeCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ClippingCls:
	"""Clipping commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("clipping", core, parent)

	def get_from_py(self) -> int:
		"""SCPI: [SOURce<HW>]:IQ:OUTPut:[ANALog]:ENVelope:SHAPing:CLIPping:FROM \n
		Snippet: value: int = driver.source.iq.output.analog.envelope.shaping.clipping.get_from_py() \n
		Enables clipping and defines its limits. \n
			:return: clipping_from: integer Range: 0 to 100
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:IQ:OUTPut:ANALog:ENVelope:SHAPing:CLIPping:FROM?')
		return Conversions.str_to_int(response)

	def set_from_py(self, clipping_from: int) -> None:
		"""SCPI: [SOURce<HW>]:IQ:OUTPut:[ANALog]:ENVelope:SHAPing:CLIPping:FROM \n
		Snippet: driver.source.iq.output.analog.envelope.shaping.clipping.set_from_py(clipping_from = 1) \n
		Enables clipping and defines its limits. \n
			:param clipping_from: integer Range: 0 to 100
		"""
		param = Conversions.decimal_value_to_str(clipping_from)
		self._core.io.write(f'SOURce<HwInstance>:IQ:OUTPut:ANALog:ENVelope:SHAPing:CLIPping:FROM {param}')

	def get_to(self) -> int:
		"""SCPI: [SOURce<HW>]:IQ:OUTPut:[ANALog]:ENVelope:SHAPing:CLIPping:TO \n
		Snippet: value: int = driver.source.iq.output.analog.envelope.shaping.clipping.get_to() \n
		Enables clipping and defines its limits. \n
			:return: clipping_to: integer Range: 0 to 100
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:IQ:OUTPut:ANALog:ENVelope:SHAPing:CLIPping:TO?')
		return Conversions.str_to_int(response)

	def set_to(self, clipping_to: int) -> None:
		"""SCPI: [SOURce<HW>]:IQ:OUTPut:[ANALog]:ENVelope:SHAPing:CLIPping:TO \n
		Snippet: driver.source.iq.output.analog.envelope.shaping.clipping.set_to(clipping_to = 1) \n
		Enables clipping and defines its limits. \n
			:param clipping_to: integer Range: 0 to 100
		"""
		param = Conversions.decimal_value_to_str(clipping_to)
		self._core.io.write(f'SOURce<HwInstance>:IQ:OUTPut:ANALog:ENVelope:SHAPing:CLIPping:TO {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PhaseCls:
	"""Phase commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("phase", core, parent)

	def get_step(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:MCARrier:EDIT:CARRier:PHASe:STEP \n
		Snippet: value: float = driver.source.bb.arbitrary.mcarrier.edit.carrier.phase.get_step() \n
		The command sets the step width by which the start phases of the carriers in the defined carrier range will be
		incremented. The phase settings are only valid if optimization of the crest factor is disabled
		(SOURce:BB:ARB:MCARrier:CFACtor:MODE OFF) . \n
			:return: step: float Range: -359.99 to 359.99, Unit: DEG
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:MCARrier:EDIT:CARRier:PHASe:STEP?')
		return Conversions.str_to_float(response)

	def set_step(self, step: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:MCARrier:EDIT:CARRier:PHASe:STEP \n
		Snippet: driver.source.bb.arbitrary.mcarrier.edit.carrier.phase.set_step(step = 1.0) \n
		The command sets the step width by which the start phases of the carriers in the defined carrier range will be
		incremented. The phase settings are only valid if optimization of the crest factor is disabled
		(SOURce:BB:ARB:MCARrier:CFACtor:MODE OFF) . \n
			:param step: float Range: -359.99 to 359.99, Unit: DEG
		"""
		param = Conversions.decimal_value_to_str(step)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:MCARrier:EDIT:CARRier:PHASe:STEP {param}')

	def get_start(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:MCARrier:EDIT:CARRier:PHASe:[STARt] \n
		Snippet: value: float = driver.source.bb.arbitrary.mcarrier.edit.carrier.phase.get_start() \n
		The command sets the start phase for the individual carriers in the defined carrier range.
		If the command BB:ARB:MCAR:EDIT:CARR:PHAS:STEP is used to define a step width, the phase entered here applies only to the
		starting carrier. The phases of the remaining carriers are stepped up or down by the phase value specified in the
		BB:ARB:MCAR:EDIT:CARR:PHAS:STEP command. The phase settings are only valid if optimization of the crest factor is
		disabled (SOURce:BB:ARB:MCARrier:CFACtor:MODE OFF) . \n
			:return: start: float Range: 0 to 359.99, Unit: DEG
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:MCARrier:EDIT:CARRier:PHASe:STARt?')
		return Conversions.str_to_float(response)

	def set_start(self, start: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:MCARrier:EDIT:CARRier:PHASe:[STARt] \n
		Snippet: driver.source.bb.arbitrary.mcarrier.edit.carrier.phase.set_start(start = 1.0) \n
		The command sets the start phase for the individual carriers in the defined carrier range.
		If the command BB:ARB:MCAR:EDIT:CARR:PHAS:STEP is used to define a step width, the phase entered here applies only to the
		starting carrier. The phases of the remaining carriers are stepped up or down by the phase value specified in the
		BB:ARB:MCAR:EDIT:CARR:PHAS:STEP command. The phase settings are only valid if optimization of the crest factor is
		disabled (SOURce:BB:ARB:MCARrier:CFACtor:MODE OFF) . \n
			:param start: float Range: 0 to 359.99, Unit: DEG
		"""
		param = Conversions.decimal_value_to_str(start)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:MCARrier:EDIT:CARRier:PHASe:STARt {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ExecuteCls:
	"""Execute commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("execute", core, parent)

	def set(self) -> None:
		"""SCPI: [SOURce<HW>]:CORRection:DEXChange:EXECute \n
		Snippet: driver.source.correction.dexchange.execute.set() \n
		Starts the export or import of the selected file. When import is selected, the ASCII file is imported as user correction
		list. When export is selected, the user correction list is exported into the selected ASCII file. \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:CORRection:DEXChange:EXECute')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SOURce<HW>]:CORRection:DEXChange:EXECute \n
		Snippet: driver.source.correction.dexchange.execute.set_with_opc() \n
		Starts the export or import of the selected file. When import is selected, the ASCII file is imported as user correction
		list. When export is selected, the user correction list is exported into the selected ASCII file. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsSgt.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:CORRection:DEXChange:EXECute', opc_timeout_ms)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ServoingCls:
	"""Servoing commands group definition. 8 total commands, 1 Subgroups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("servoing", core, parent)

	@property
	def sensor(self):
		"""sensor commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_sensor'):
			from .Sensor import SensorCls
			self._sensor = SensorCls(self._core, self._cmd_group)
		return self._sensor

	# noinspection PyTypeChecker
	class SetStruct(StructBase):  # From ReadStructDefinition CmdPropertyTemplate.xml
		"""Structure for reading output parameters. Fields: \n
			- Target: float: float Starts a single power servoing setting cycle, see 'About power servoing'. Sets the desired output power level required at the DUT, see[:SOURce]:POWer:SERVoing:TARGet.
			- Start: enums.Test: 0| 1| RUNning| STOPped Queries the current status of the powerservoing procedure. 0|RUNning Procedure is ok and or running without errors. 1|STOPped Procedure is stopped due to an error."""
		__meta_args_list = [
			ArgStruct.scalar_float('Target'),
			ArgStruct.scalar_enum('Start', enums.Test)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Target: float = None
			self.Start: enums.Test = None

	def get_set(self) -> SetStruct:
		"""SCPI: [SOURce<HW>]:POWer:SERVoing:SET \n
		Snippet: value: SetStruct = driver.source.power.servoing.get_set() \n
		Sets the target output power level and queries power servoing procedure status. \n
			:return: structure: for return value, see the help for SetStruct structure arguments.
		"""
		return self._core.io.query_struct('SOURce<HwInstance>:POWer:SERVoing:SET?', self.__class__.SetStruct())

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:POWer:SERVoing:STATe \n
		Snippet: value: bool = driver.source.power.servoing.get_state() \n
		Activates/deactivates power servoing. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:POWer:SERVoing:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:POWer:SERVoing:STATe \n
		Snippet: driver.source.power.servoing.set_state(state = False) \n
		Activates/deactivates power servoing. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:POWer:SERVoing:STATe {param}')

	def get_target(self) -> float:
		"""SCPI: [SOURce<HW>]:POWer:SERVoing:TARGet \n
		Snippet: value: float = driver.source.power.servoing.get_target() \n
		Sets the target output power level required at the DUT. \n
			:return: target_level: float Range: -120 to 25
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:POWer:SERVoing:TARGet?')
		return Conversions.str_to_float(response)

	def set_target(self, target_level: float) -> None:
		"""SCPI: [SOURce<HW>]:POWer:SERVoing:TARGet \n
		Snippet: driver.source.power.servoing.set_target(target_level = 1.0) \n
		Sets the target output power level required at the DUT. \n
			:param target_level: float Range: -120 to 25
		"""
		param = Conversions.decimal_value_to_str(target_level)
		self._core.io.write(f'SOURce<HwInstance>:POWer:SERVoing:TARGet {param}')

	# noinspection PyTypeChecker
	def get_test(self) -> enums.Test:
		"""SCPI: [SOURce<HW>]:POWer:SERVoing:TEST \n
		Snippet: value: enums.Test = driver.source.power.servoing.get_test() \n
		Queries the state of the power servoing procedure. \n
			:return: start: 0| 1| RUNning| STOPped
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:POWer:SERVoing:TEST?')
		return Conversions.str_to_scalar_enum(response, enums.Test)

	def get_tolerance(self) -> float:
		"""SCPI: [SOURce<HW>]:POWer:SERVoing:TOLerance \n
		Snippet: value: float = driver.source.power.servoing.get_tolerance() \n
		Sets the tolerance level interval, in which the 'Target' output power level of the DUT lies.
		A large tolerance accelerates the power servoing procedure but also reduces the accuracy of the target output power level. \n
			:return: tolerance: float Range: 0.01 to 3
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:POWer:SERVoing:TOLerance?')
		return Conversions.str_to_float(response)

	def set_tolerance(self, tolerance: float) -> None:
		"""SCPI: [SOURce<HW>]:POWer:SERVoing:TOLerance \n
		Snippet: driver.source.power.servoing.set_tolerance(tolerance = 1.0) \n
		Sets the tolerance level interval, in which the 'Target' output power level of the DUT lies.
		A large tolerance accelerates the power servoing procedure but also reduces the accuracy of the target output power level. \n
			:param tolerance: float Range: 0.01 to 3
		"""
		param = Conversions.decimal_value_to_str(tolerance)
		self._core.io.write(f'SOURce<HwInstance>:POWer:SERVoing:TOLerance {param}')

	def get_tracking(self) -> bool:
		"""SCPI: [SOURce<HW>]:POWer:SERVoing:TRACking \n
		Snippet: value: bool = driver.source.power.servoing.get_tracking() \n
		Activates/deactivates level tracking. Activation increases measurement accuracy but also measurement time. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:POWer:SERVoing:TRACking?')
		return Conversions.str_to_bool(response)

	def set_tracking(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:POWer:SERVoing:TRACking \n
		Snippet: driver.source.power.servoing.set_tracking(state = False) \n
		Activates/deactivates level tracking. Activation increases measurement accuracy but also measurement time. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:POWer:SERVoing:TRACking {param}')

	def clone(self) -> 'ServoingCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ServoingCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FileCls:
	"""File commands group definition. 4 total commands, 0 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("file", core, parent)

	def get_catalog(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:IQ:OUTPut:[ANALog]:ENVelope:SHAPing:FILE:CATalog \n
		Snippet: value: List[str] = driver.source.iq.output.analog.envelope.shaping.file.get_catalog() \n
		Queries the available table shaping files in the default directory. Only files with the file extension *.iq_lut or *.
		iq_lutpv are listed. \n
			:return: catalog: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:IQ:OUTPut:ANALog:ENVelope:SHAPing:FILE:CATalog?')
		return Conversions.str_to_str_list(response)

	def get_data(self) -> List[float]:
		"""SCPI: [SOURce<HW>]:IQ:OUTPut:[ANALog]:ENVelope:SHAPing:FILE:DATA \n
		Snippet: value: List[float] = driver.source.iq.output.analog.envelope.shaping.file.get_data() \n
		Defines the shaping function in a raw data format. See also [:SOURce<hw>]:IQ:OUTPut[:ANALog]:ENVelope:SHAPing:PV:FILE:NEW. \n
			:return: ipartq_out_env_shape_data: No help available
		"""
		response = self._core.io.query_bin_or_ascii_float_list('SOURce<HwInstance>:IQ:OUTPut:ANALog:ENVelope:SHAPing:FILE:DATA?')
		return response

	def set_data(self, ipartq_out_env_shape_data: List[float]) -> None:
		"""SCPI: [SOURce<HW>]:IQ:OUTPut:[ANALog]:ENVelope:SHAPing:FILE:DATA \n
		Snippet: driver.source.iq.output.analog.envelope.shaping.file.set_data(ipartq_out_env_shape_data = [1.1, 2.2, 3.3]) \n
		Defines the shaping function in a raw data format. See also [:SOURce<hw>]:IQ:OUTPut[:ANALog]:ENVelope:SHAPing:PV:FILE:NEW. \n
			:param ipartq_out_env_shape_data: No help available
		"""
		param = Conversions.list_to_csv_str(ipartq_out_env_shape_data)
		self._core.io.write(f'SOURce<HwInstance>:IQ:OUTPut:ANALog:ENVelope:SHAPing:FILE:DATA {param}')

	def set_new(self, ipartd_pi_db_iq_out_env_shape_data_new_file: List[float]) -> None:
		"""SCPI: [SOURce<HW>]:IQ:OUTPut:[ANALog]:ENVelope:SHAPing:FILE:NEW \n
		Snippet: driver.source.iq.output.analog.envelope.shaping.file.set_new(ipartd_pi_db_iq_out_env_shape_data_new_file = [1.1, 2.2, 3.3]) \n
		Stores the shaping values into a file with the selected file name and loads it. The file is stored in the default
		directory or in the directory specified with the absolute file path. If the file does not yet exist, a new file is
		created. The file extension is assigned automatically. \n
			:param ipartd_pi_db_iq_out_env_shape_data_new_file: No help available
		"""
		param = Conversions.list_to_csv_str(ipartd_pi_db_iq_out_env_shape_data_new_file)
		self._core.io.write(f'SOURce<HwInstance>:IQ:OUTPut:ANALog:ENVelope:SHAPing:FILE:NEW {param}')

	def get_select(self) -> str:
		"""SCPI: [SOURce<HW>]:IQ:OUTPut:[ANALog]:ENVelope:SHAPing:FILE:[SELect] \n
		Snippet: value: str = driver.source.iq.output.analog.envelope.shaping.file.get_select() \n
		Selects an envelope shaping file (extension *.iq_lut or *.iq_lutpv) . \n
			:return: filename: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:IQ:OUTPut:ANALog:ENVelope:SHAPing:FILE:SELect?')
		return trim_str_response(response)

	def set_select(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:IQ:OUTPut:[ANALog]:ENVelope:SHAPing:FILE:[SELect] \n
		Snippet: driver.source.iq.output.analog.envelope.shaping.file.set_select(filename = '1') \n
		Selects an envelope shaping file (extension *.iq_lut or *.iq_lutpv) . \n
			:param filename: string
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:IQ:OUTPut:ANALog:ENVelope:SHAPing:FILE:SELect {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StoreCls:
	"""Store commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("store", core, parent)

	def get_fast(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:MCARrier:SETTing:STORe:FAST \n
		Snippet: value: bool = driver.source.bb.arbitrary.mcarrier.setting.store.get_fast() \n
		Determines whether the instrument performs an absolute or a differential storing of the settings. Enable this function to
		accelerate the saving process by saving only the settings with values different to the default ones. Note: This function
		is not affected by the 'Preset' function. \n
			:return: fast: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:MCARrier:SETTing:STORe:FAST?')
		return Conversions.str_to_bool(response)

	def set_fast(self, fast: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:MCARrier:SETTing:STORe:FAST \n
		Snippet: driver.source.bb.arbitrary.mcarrier.setting.store.set_fast(fast = False) \n
		Determines whether the instrument performs an absolute or a differential storing of the settings. Enable this function to
		accelerate the saving process by saving only the settings with values different to the default ones. Note: This function
		is not affected by the 'Preset' function. \n
			:param fast: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(fast)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:MCARrier:SETTing:STORe:FAST {param}')

	def set_value(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:MCARrier:SETTing:STORe \n
		Snippet: driver.source.bb.arbitrary.mcarrier.setting.store.set_value(filename = '1') \n
		The command stores the current settings of submenu 'Multi Carrier' in a file in the specified directory.
		The file extension may be omitted, the files are stored with the file extension *.arb_multcarr. \n
			:param filename: string
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:MCARrier:SETTing:STORe {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RectangleCls:
	"""Rectangle commands group definition. 6 total commands, 1 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rectangle", core, parent)

	@property
	def create(self):
		"""create commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_create'):
			from .Create import CreateCls
			self._create = CreateCls(self._core, self._cmd_group)
		return self._create

	def get_amplitude(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:TSIGnal:RECTangle:AMPLitude \n
		Snippet: value: float = driver.source.bb.arbitrary.tsignal.rectangle.get_amplitude() \n
		Sets the digital amplitude of the rectangular wave. \n
			:return: amplitude: float Range: 0 to 1, Unit: FS
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:TSIGnal:RECTangle:AMPLitude?')
		return Conversions.str_to_float(response)

	def set_amplitude(self, amplitude: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:TSIGnal:RECTangle:AMPLitude \n
		Snippet: driver.source.bb.arbitrary.tsignal.rectangle.set_amplitude(amplitude = 1.0) \n
		Sets the digital amplitude of the rectangular wave. \n
			:param amplitude: float Range: 0 to 1, Unit: FS
		"""
		param = Conversions.decimal_value_to_str(amplitude)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:TSIGnal:RECTangle:AMPLitude {param}')

	def get_frequency(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:TSIGnal:RECTangle:FREQuency \n
		Snippet: value: float = driver.source.bb.arbitrary.tsignal.rectangle.get_frequency() \n
		Sets the frequency of the test signal. \n
			:return: frequency: float Range: 100 to depends on hardware
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:TSIGnal:RECTangle:FREQuency?')
		return Conversions.str_to_float(response)

	def set_frequency(self, frequency: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:TSIGnal:RECTangle:FREQuency \n
		Snippet: driver.source.bb.arbitrary.tsignal.rectangle.set_frequency(frequency = 1.0) \n
		Sets the frequency of the test signal. \n
			:param frequency: float Range: 100 to depends on hardware
		"""
		param = Conversions.decimal_value_to_str(frequency)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:TSIGnal:RECTangle:FREQuency {param}')

	def get_offset(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:TSIGnal:RECTangle:OFFSet \n
		Snippet: value: float = driver.source.bb.arbitrary.tsignal.rectangle.get_offset() \n
		Sets the DC component. \n
			:return: offset: float Range: -1 to 1, Unit: FS
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:TSIGnal:RECTangle:OFFSet?')
		return Conversions.str_to_float(response)

	def set_offset(self, offset: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:TSIGnal:RECTangle:OFFSet \n
		Snippet: driver.source.bb.arbitrary.tsignal.rectangle.set_offset(offset = 1.0) \n
		Sets the DC component. \n
			:param offset: float Range: -1 to 1, Unit: FS
		"""
		param = Conversions.decimal_value_to_str(offset)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:TSIGnal:RECTangle:OFFSet {param}')

	def get_samples(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:TSIGnal:RECTangle:SAMPles \n
		Snippet: value: int = driver.source.bb.arbitrary.tsignal.rectangle.get_samples() \n
		Sets the number of sample values required for the rectangular signal per period. \n
			:return: samples: integer Range: 4 to 1000
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ARBitrary:TSIGnal:RECTangle:SAMPles?')
		return Conversions.str_to_int(response)

	def set_samples(self, samples: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:ARBitrary:TSIGnal:RECTangle:SAMPles \n
		Snippet: driver.source.bb.arbitrary.tsignal.rectangle.set_samples(samples = 1) \n
		Sets the number of sample values required for the rectangular signal per period. \n
			:param samples: integer Range: 4 to 1000
		"""
		param = Conversions.decimal_value_to_str(samples)
		self._core.io.write(f'SOURce<HwInstance>:BB:ARBitrary:TSIGnal:RECTangle:SAMPles {param}')

	def clone(self) -> 'RectangleCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RectangleCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CsetCls:
	"""Cset commands group definition. 8 total commands, 1 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cset", core, parent)

	@property
	def data(self):
		"""data commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_data'):
			from .Data import DataCls
			self._data = DataCls(self._core, self._cmd_group)
		return self._data

	def get_catalog(self) -> List[str]:
		"""SCPI: [SOURce]:CORRection:CSET:CATalog \n
		Snippet: value: List[str] = driver.source.correction.cset.get_catalog() \n
		Requests a list of user correction tables. The individual lists are separated by commas. The lists are stored with the
		fixed file extensions *.uco in a directory of the user's choice. The directory applicable to the commands is defined with
		the command method RsSgt.MassMemory.currentDirectory. \n
			:return: catalog: string
		"""
		response = self._core.io.query_str('SOURce:CORRection:CSET:CATalog?')
		return Conversions.str_to_str_list(response)

	def delete(self, filename: str) -> None:
		"""SCPI: [SOURce]:CORRection:CSET:DELete \n
		Snippet: driver.source.correction.cset.delete(filename = '1') \n
		Deletes the specified table. The lists are stored with the fixed file extensions *.uco in a directory of the user's
		choice. The directory applicable to the commands is defined with the command method RsSgt.MassMemory.currentDirectory. A
		path can also be specified in command SOUR:CORR:CSET:CAT?, in which case the file in the specified directory is deleted. \n
			:param filename: table name
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce:CORRection:CSET:DELete {param}')

	def get_select(self) -> str:
		"""SCPI: [SOURce<HW>]:CORRection:CSET:[SELect] \n
		Snippet: value: str = driver.source.correction.cset.get_select() \n
		Selects or creates a file for the user correction data. If the file does not exist, the instrument automatically creates
		a new file with the name you assigned. Note the predefined file extensions under 'Extensions for user files'.
		To determine the file location (directory/path) you can either enter it with the command directly, or use the command
		method RsSgt.MassMemory.currentDirectory. To activate level correction use the command [:SOURce<hw>]:CORRection[:STATe]. \n
			:return: filename: table name
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:CORRection:CSET:SELect?')
		return trim_str_response(response)

	def set_select(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:CORRection:CSET:[SELect] \n
		Snippet: driver.source.correction.cset.set_select(filename = '1') \n
		Selects or creates a file for the user correction data. If the file does not exist, the instrument automatically creates
		a new file with the name you assigned. Note the predefined file extensions under 'Extensions for user files'.
		To determine the file location (directory/path) you can either enter it with the command directly, or use the command
		method RsSgt.MassMemory.currentDirectory. To activate level correction use the command [:SOURce<hw>]:CORRection[:STATe]. \n
			:param filename: table name
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:CORRection:CSET:SELect {param}')

	def clone(self) -> 'CsetCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CsetCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group
